Files
MINGW-packages/mingw-w64-nodejs/0101-Fixing-for-python2-name.patch
2014-07-26 13:56:44 +01:00

1111 lines
59 KiB
Diff

diff -urN node-v0.10.29.orig/common.gypi node-v0.10.29/common.gypi
--- node-v0.10.29.orig/common.gypi 2014-07-21 00:59:16.247854207 +0100
+++ node-v0.10.29/common.gypi 2014-07-21 00:59:16.387926352 +0100
@@ -10,7 +10,7 @@
'msvs_multi_core_compile': '0', # we do enable multicore compiles, but not using the V8 way
'gcc_version%': 'unknown',
'clang%': 0,
- 'python%': 'python',
+ 'python%': 'python2',
# Turn on optimizations that may trigger compiler bugs.
# Use at your own risk. Do *NOT* report bugs if this option is enabled.
diff -urN node-v0.10.29.orig/configure node-v0.10.29/configure
--- node-v0.10.29.orig/configure 2014-07-21 00:59:16.247854207 +0100
+++ node-v0.10.29/configure 2014-07-21 00:59:16.391261409 +0100
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/python2
import optparse
import os
import pprint
diff -urN node-v0.10.29.orig/deps/cares/build/gcc_version.py node-v0.10.29/deps/cares/build/gcc_version.py
--- node-v0.10.29.orig/deps/cares/build/gcc_version.py 2014-07-21 00:59:16.377921190 +0100
+++ node-v0.10.29/deps/cares/build/gcc_version.py 2014-07-21 00:59:33.566776899 +0100
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
import os
import re
diff -urN node-v0.10.29.orig/deps/npm/node_modules/node-gyp/gyp/buildbot/buildbot_run.py node-v0.10.29/deps/npm/node_modules/node-gyp/gyp/buildbot/buildbot_run.py
--- node-v0.10.29.orig/deps/npm/node_modules/node-gyp/gyp/buildbot/buildbot_run.py 2014-07-21 00:59:16.354575853 +0100
+++ node-v0.10.29/deps/npm/node_modules/node-gyp/gyp/buildbot/buildbot_run.py 2014-07-21 00:59:30.858715047 +0100
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
# Copyright (c) 2012 Google Inc. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
# found in the LICENSE file.
diff -urN node-v0.10.29.orig/deps/npm/node_modules/node-gyp/gyp/gyp_main.py node-v0.10.29/deps/npm/node_modules/node-gyp/gyp/gyp_main.py
--- node-v0.10.29.orig/deps/npm/node_modules/node-gyp/gyp/gyp_main.py 2014-07-21 00:59:16.354575853 +0100
+++ node-v0.10.29/deps/npm/node_modules/node-gyp/gyp/gyp_main.py 2014-07-21 00:59:30.845374822 +0100
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
# Copyright (c) 2009 Google Inc. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
diff -urN node-v0.10.29.orig/deps/npm/node_modules/node-gyp/gyp/gyptest.py node-v0.10.29/deps/npm/node_modules/node-gyp/gyp/gyptest.py
--- node-v0.10.29.orig/deps/npm/node_modules/node-gyp/gyp/gyptest.py 2014-07-21 00:59:16.354575853 +0100
+++ node-v0.10.29/deps/npm/node_modules/node-gyp/gyp/gyptest.py 2014-07-21 00:59:31.002122243 +0100
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
# Copyright (c) 2012 Google Inc. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
diff -urN node-v0.10.29.orig/deps/npm/node_modules/node-gyp/gyp/pylib/gyp/common_test.py node-v0.10.29/deps/npm/node_modules/node-gyp/gyp/pylib/gyp/common_test.py
--- node-v0.10.29.orig/deps/npm/node_modules/node-gyp/gyp/pylib/gyp/common_test.py 2014-07-21 00:59:16.354575853 +0100
+++ node-v0.10.29/deps/npm/node_modules/node-gyp/gyp/pylib/gyp/common_test.py 2014-07-21 00:59:30.985446998 +0100
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
# Copyright (c) 2012 Google Inc. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
diff -urN node-v0.10.29.orig/deps/npm/node_modules/node-gyp/gyp/pylib/gyp/easy_xml_test.py node-v0.10.29/deps/npm/node_modules/node-gyp/gyp/pylib/gyp/easy_xml_test.py
--- node-v0.10.29.orig/deps/npm/node_modules/node-gyp/gyp/pylib/gyp/easy_xml_test.py 2014-07-21 00:59:16.354575853 +0100
+++ node-v0.10.29/deps/npm/node_modules/node-gyp/gyp/pylib/gyp/easy_xml_test.py 2014-07-21 00:59:30.988782047 +0100
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
# Copyright (c) 2011 Google Inc. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
diff -urN node-v0.10.29.orig/deps/npm/node_modules/node-gyp/gyp/pylib/gyp/flock_tool.py node-v0.10.29/deps/npm/node_modules/node-gyp/gyp/pylib/gyp/flock_tool.py
--- node-v0.10.29.orig/deps/npm/node_modules/node-gyp/gyp/pylib/gyp/flock_tool.py 2014-07-21 00:59:16.354575853 +0100
+++ node-v0.10.29/deps/npm/node_modules/node-gyp/gyp/pylib/gyp/flock_tool.py 2014-07-21 00:59:30.992117099 +0100
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
# Copyright (c) 2011 Google Inc. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
# found in the LICENSE file.
diff -urN node-v0.10.29.orig/deps/npm/node_modules/node-gyp/gyp/pylib/gyp/generator/msvs_test.py node-v0.10.29/deps/npm/node_modules/node-gyp/gyp/pylib/gyp/generator/msvs_test.py
--- node-v0.10.29.orig/deps/npm/node_modules/node-gyp/gyp/pylib/gyp/generator/msvs_test.py 2014-07-21 00:59:16.354575853 +0100
+++ node-v0.10.29/deps/npm/node_modules/node-gyp/gyp/pylib/gyp/generator/msvs_test.py 2014-07-21 00:59:30.942091334 +0100
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
# Copyright (c) 2012 Google Inc. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
# found in the LICENSE file.
diff -urN node-v0.10.29.orig/deps/npm/node_modules/node-gyp/gyp/pylib/gyp/generator/ninja_test.py node-v0.10.29/deps/npm/node_modules/node-gyp/gyp/pylib/gyp/generator/ninja_test.py
--- node-v0.10.29.orig/deps/npm/node_modules/node-gyp/gyp/pylib/gyp/generator/ninja_test.py 2014-07-21 00:59:16.354575853 +0100
+++ node-v0.10.29/deps/npm/node_modules/node-gyp/gyp/pylib/gyp/generator/ninja_test.py 2014-07-21 00:59:30.948761421 +0100
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
# Copyright (c) 2012 Google Inc. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
diff -urN node-v0.10.29.orig/deps/npm/node_modules/node-gyp/gyp/pylib/gyp/generator/xcode_test.py node-v0.10.29/deps/npm/node_modules/node-gyp/gyp/pylib/gyp/generator/xcode_test.py
--- node-v0.10.29.orig/deps/npm/node_modules/node-gyp/gyp/pylib/gyp/generator/xcode_test.py 2014-07-21 00:59:16.354575853 +0100
+++ node-v0.10.29/deps/npm/node_modules/node-gyp/gyp/pylib/gyp/generator/xcode_test.py 2014-07-21 00:59:30.918745956 +0100
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
# Copyright (c) 2013 Google Inc. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
diff -urN node-v0.10.29.orig/deps/npm/node_modules/node-gyp/gyp/pylib/gyp/__init__.py node-v0.10.29/deps/npm/node_modules/node-gyp/gyp/pylib/gyp/__init__.py
--- node-v0.10.29.orig/deps/npm/node_modules/node-gyp/gyp/pylib/gyp/__init__.py 2014-07-21 00:59:16.354575853 +0100
+++ node-v0.10.29/deps/npm/node_modules/node-gyp/gyp/pylib/gyp/__init__.py 2014-07-21 00:59:30.865385118 +0100
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
# Copyright (c) 2012 Google Inc. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
diff -urN node-v0.10.29.orig/deps/npm/node_modules/node-gyp/gyp/pylib/gyp/input_test.py node-v0.10.29/deps/npm/node_modules/node-gyp/gyp/pylib/gyp/input_test.py
--- node-v0.10.29.orig/deps/npm/node_modules/node-gyp/gyp/pylib/gyp/input_test.py 2014-07-21 00:59:16.354575853 +0100
+++ node-v0.10.29/deps/npm/node_modules/node-gyp/gyp/pylib/gyp/input_test.py 2014-07-21 00:59:30.895400595 +0100
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
# Copyright 2013 Google Inc. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
diff -urN node-v0.10.29.orig/deps/npm/node_modules/node-gyp/gyp/pylib/gyp/mac_tool.py node-v0.10.29/deps/npm/node_modules/node-gyp/gyp/pylib/gyp/mac_tool.py
--- node-v0.10.29.orig/deps/npm/node_modules/node-gyp/gyp/pylib/gyp/mac_tool.py 2014-07-21 00:59:16.354575853 +0100
+++ node-v0.10.29/deps/npm/node_modules/node-gyp/gyp/pylib/gyp/mac_tool.py 2014-07-21 00:59:30.982111952 +0100
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
# Copyright (c) 2012 Google Inc. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
# found in the LICENSE file.
diff -urN node-v0.10.29.orig/deps/npm/node_modules/node-gyp/gyp/pylib/gyp/MSVSSettings_test.py node-v0.10.29/deps/npm/node_modules/node-gyp/gyp/pylib/gyp/MSVSSettings_test.py
--- node-v0.10.29.orig/deps/npm/node_modules/node-gyp/gyp/pylib/gyp/MSVSSettings_test.py 2014-07-21 00:59:16.354575853 +0100
+++ node-v0.10.29/deps/npm/node_modules/node-gyp/gyp/pylib/gyp/MSVSSettings_test.py 2014-07-21 00:59:30.998787191 +0100
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
# Copyright (c) 2012 Google Inc. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
diff -urN node-v0.10.29.orig/deps/npm/node_modules/node-gyp/gyp/pylib/gyp/win_tool.py node-v0.10.29/deps/npm/node_modules/node-gyp/gyp/pylib/gyp/win_tool.py
--- node-v0.10.29.orig/deps/npm/node_modules/node-gyp/gyp/pylib/gyp/win_tool.py 2014-07-21 00:59:16.354575853 +0100
+++ node-v0.10.29/deps/npm/node_modules/node-gyp/gyp/pylib/gyp/win_tool.py 2014-07-21 00:59:30.892065546 +0100
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
# Copyright (c) 2012 Google Inc. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
diff -urN node-v0.10.29.orig/deps/npm/node_modules/node-gyp/gyp/samples/samples node-v0.10.29/deps/npm/node_modules/node-gyp/gyp/samples/samples
--- node-v0.10.29.orig/deps/npm/node_modules/node-gyp/gyp/samples/samples 2014-07-21 00:59:16.354575853 +0100
+++ node-v0.10.29/deps/npm/node_modules/node-gyp/gyp/samples/samples 2014-07-21 00:59:30.852044931 +0100
@@ -1,4 +1,4 @@
-#!/usr/bin/python
+#!/usr/bin/python2
# Copyright (c) 2009 Google Inc. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
diff -urN node-v0.10.29.orig/deps/npm/node_modules/node-gyp/gyp/setup.py node-v0.10.29/deps/npm/node_modules/node-gyp/gyp/setup.py
--- node-v0.10.29.orig/deps/npm/node_modules/node-gyp/gyp/setup.py 2014-07-21 00:59:16.354575853 +0100
+++ node-v0.10.29/deps/npm/node_modules/node-gyp/gyp/setup.py 2014-07-21 00:59:30.855379978 +0100
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
# Copyright (c) 2009 Google Inc. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
diff -urN node-v0.10.29.orig/deps/npm/node_modules/node-gyp/gyp/tools/emacs/testdata/media.gyp node-v0.10.29/deps/npm/node_modules/node-gyp/gyp/tools/emacs/testdata/media.gyp
--- node-v0.10.29.orig/deps/npm/node_modules/node-gyp/gyp/tools/emacs/testdata/media.gyp 2014-07-21 00:59:16.354575853 +0100
+++ node-v0.10.29/deps/npm/node_modules/node-gyp/gyp/tools/emacs/testdata/media.gyp 2014-07-21 00:59:31.028802677 +0100
@@ -987,7 +987,7 @@
'<(SHARED_INTERMEDIATE_DIR)/media/jni/media_player_listener_jni.h',
],
'action': [
- 'python',
+ 'python2',
'<(DEPTH)/base/android/jni_generator/jni_generator.py',
'-o',
'<@(_inputs)',
diff -urN node-v0.10.29.orig/deps/npm/node_modules/node-gyp/gyp/tools/emacs/testdata/media.gyp.fontified node-v0.10.29/deps/npm/node_modules/node-gyp/gyp/tools/emacs/testdata/media.gyp.fontified
--- node-v0.10.29.orig/deps/npm/node_modules/node-gyp/gyp/tools/emacs/testdata/media.gyp.fontified 2014-07-21 00:59:16.354575853 +0100
+++ node-v0.10.29/deps/npm/node_modules/node-gyp/gyp/tools/emacs/testdata/media.gyp.fontified 2014-07-21 00:59:31.032137702 +0100
@@ -988,7 +988,7 @@
'<(SHARED_INTERMEDIATE_DIR)/media/jni/media_player_listener_jni.h',
],
'action': [
- 'python',
+ 'python2',
'<(DEPTH)/base/android/jni_generator/jni_generator.py',
'-o',
'<@(_inputs)',
diff -urN node-v0.10.29.orig/deps/npm/node_modules/node-gyp/gyp/tools/graphviz.py node-v0.10.29/deps/npm/node_modules/node-gyp/gyp/tools/graphviz.py
--- node-v0.10.29.orig/deps/npm/node_modules/node-gyp/gyp/tools/graphviz.py 2014-07-21 00:59:16.354575853 +0100
+++ node-v0.10.29/deps/npm/node_modules/node-gyp/gyp/tools/graphviz.py 2014-07-21 00:59:31.015462479 +0100
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
# Copyright (c) 2011 Google Inc. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
diff -urN node-v0.10.29.orig/deps/npm/node_modules/node-gyp/gyp/tools/pretty_gyp.py node-v0.10.29/deps/npm/node_modules/node-gyp/gyp/tools/pretty_gyp.py
--- node-v0.10.29.orig/deps/npm/node_modules/node-gyp/gyp/tools/pretty_gyp.py 2014-07-21 00:59:16.354575853 +0100
+++ node-v0.10.29/deps/npm/node_modules/node-gyp/gyp/tools/pretty_gyp.py 2014-07-21 00:59:31.008792341 +0100
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
# Copyright (c) 2012 Google Inc. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
diff -urN node-v0.10.29.orig/deps/npm/node_modules/node-gyp/gyp/tools/pretty_sln.py node-v0.10.29/deps/npm/node_modules/node-gyp/gyp/tools/pretty_sln.py
--- node-v0.10.29.orig/deps/npm/node_modules/node-gyp/gyp/tools/pretty_sln.py 2014-07-21 00:59:16.354575853 +0100
+++ node-v0.10.29/deps/npm/node_modules/node-gyp/gyp/tools/pretty_sln.py 2014-07-21 00:59:31.045477908 +0100
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
# Copyright (c) 2012 Google Inc. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
diff -urN node-v0.10.29.orig/deps/npm/node_modules/node-gyp/gyp/tools/pretty_vcproj.py node-v0.10.29/deps/npm/node_modules/node-gyp/gyp/tools/pretty_vcproj.py
--- node-v0.10.29.orig/deps/npm/node_modules/node-gyp/gyp/tools/pretty_vcproj.py 2014-07-21 00:59:16.354575853 +0100
+++ node-v0.10.29/deps/npm/node_modules/node-gyp/gyp/tools/pretty_vcproj.py 2014-07-21 00:59:31.008792341 +0100
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
# Copyright (c) 2012 Google Inc. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
diff -urN node-v0.10.29.orig/deps/npm/node_modules/node-gyp/README.md node-v0.10.29/deps/npm/node_modules/node-gyp/README.md
--- node-v0.10.29.orig/deps/npm/node_modules/node-gyp/README.md 2014-07-21 00:59:16.357910894 +0100
+++ node-v0.10.29/deps/npm/node_modules/node-gyp/README.md 2014-07-21 00:59:31.068823295 +0100
@@ -53,7 +53,7 @@
```
If `node-gyp` is called by way of `npm` *and* you have multiple versions of
-Python installed, then you can set `npm`'s 'python' config key to the appropriate
+Python installed, then you can set `npm`'s 'python2' config key to the appropriate
value:
``` bash
diff -urN node-v0.10.29.orig/deps/uv/gyp_uv.py node-v0.10.29/deps/uv/gyp_uv.py
--- node-v0.10.29.orig/deps/uv/gyp_uv.py 2014-07-21 00:59:16.337900617 +0100
+++ node-v0.10.29/deps/uv/gyp_uv.py 2014-07-21 00:59:28.951065546 +0100
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
import glob
import platform
diff -urN node-v0.10.29.orig/deps/v8/build/gyp_v8 node-v0.10.29/deps/v8/build/gyp_v8
--- node-v0.10.29.orig/deps/v8/build/gyp_v8 2014-07-21 00:59:16.287874794 +0100
+++ node-v0.10.29/deps/v8/build/gyp_v8 2014-07-21 00:59:21.870751110 +0100
@@ -1,4 +1,4 @@
-#!/usr/bin/python
+#!/usr/bin/python2
#
# Copyright 2012 the V8 project authors. All rights reserved.
# Redistribution and use in source and binary forms, with or without
diff -urN node-v0.10.29.orig/deps/v8/src/d8.gyp node-v0.10.29/deps/v8/src/d8.gyp
--- node-v0.10.29.orig/deps/v8/src/d8.gyp 2014-07-21 00:59:16.284539746 +0100
+++ node-v0.10.29/deps/v8/src/d8.gyp 2014-07-21 00:59:21.393838722 +0100
@@ -99,7 +99,7 @@
'<(SHARED_INTERMEDIATE_DIR)/d8-js.cc',
],
'action': [
- 'python',
+ 'python2',
'../tools/js2c.py',
'<@(_outputs)',
'D8',
diff -urN node-v0.10.29.orig/deps/v8/tools/android-run.py node-v0.10.29/deps/v8/tools/android-run.py
--- node-v0.10.29.orig/deps/v8/tools/android-run.py 2014-07-21 00:59:16.287874794 +0100
+++ node-v0.10.29/deps/v8/tools/android-run.py 2014-07-21 00:59:21.714003697 +0100
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
#
# Copyright 2012 the V8 project authors. All rights reserved.
# Redistribution and use in source and binary forms, with or without
diff -urN node-v0.10.29.orig/deps/v8/tools/disasm.py node-v0.10.29/deps/v8/tools/disasm.py
--- node-v0.10.29.orig/deps/v8/tools/disasm.py 2014-07-21 00:59:16.287874794 +0100
+++ node-v0.10.29/deps/v8/tools/disasm.py 2014-07-21 00:59:21.860745960 +0100
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
#
# Copyright 2011 the V8 project authors. All rights reserved.
# Redistribution and use in source and binary forms, with or without
diff -urN node-v0.10.29.orig/deps/v8/tools/gc-nvp-trace-processor.py node-v0.10.29/deps/v8/tools/gc-nvp-trace-processor.py
--- node-v0.10.29.orig/deps/v8/tools/gc-nvp-trace-processor.py 2014-07-21 00:59:16.287874794 +0100
+++ node-v0.10.29/deps/v8/tools/gc-nvp-trace-processor.py 2014-07-21 00:59:21.750689263 +0100
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
#
# Copyright 2010 the V8 project authors. All rights reserved.
# Redistribution and use in source and binary forms, with or without
diff -urN node-v0.10.29.orig/deps/v8/tools/gen-postmortem-metadata.py node-v0.10.29/deps/v8/tools/gen-postmortem-metadata.py
--- node-v0.10.29.orig/deps/v8/tools/gen-postmortem-metadata.py 2014-07-21 00:59:16.287874794 +0100
+++ node-v0.10.29/deps/v8/tools/gen-postmortem-metadata.py 2014-07-21 00:59:21.657307766 +0100
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
#
# Copyright 2012 the V8 project authors. All rights reserved.
diff -urN node-v0.10.29.orig/deps/v8/tools/grokdump.py node-v0.10.29/deps/v8/tools/grokdump.py
--- node-v0.10.29.orig/deps/v8/tools/grokdump.py 2014-07-21 00:59:16.287874794 +0100
+++ node-v0.10.29/deps/v8/tools/grokdump.py 2014-07-21 00:59:21.744019143 +0100
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
#
# Copyright 2012 the V8 project authors. All rights reserved.
# Redistribution and use in source and binary forms, with or without
diff -urN node-v0.10.29.orig/deps/v8/tools/gyp/v8.gyp node-v0.10.29/deps/v8/tools/gyp/v8.gyp
--- node-v0.10.29.orig/deps/v8/tools/gyp/v8.gyp 2014-07-21 00:59:16.287874794 +0100
+++ node-v0.10.29/deps/v8/tools/gyp/v8.gyp 2014-07-21 00:59:21.633962449 +0100
@@ -798,7 +798,7 @@
'<(SHARED_INTERMEDIATE_DIR)/libraries.cc',
],
'action': [
- 'python',
+ 'python2',
'../../tools/js2c.py',
'<@(_outputs)',
'CORE',
@@ -816,7 +816,7 @@
'<(SHARED_INTERMEDIATE_DIR)/experimental-libraries.cc',
],
'action': [
- 'python',
+ 'python2',
'../../tools/js2c.py',
'<@(_outputs)',
'EXPERIMENTAL',
@@ -846,7 +846,7 @@
'<(SHARED_INTERMEDIATE_DIR)/debug-support.cc',
],
'action': [
- 'python',
+ 'python2',
'../../tools/gen-postmortem-metadata.py',
'<@(_outputs)',
'<@(heapobject_files)'
diff -urN node-v0.10.29.orig/deps/v8/tools/js2c.py node-v0.10.29/deps/v8/tools/js2c.py
--- node-v0.10.29.orig/deps/v8/tools/js2c.py 2014-07-21 00:59:16.287874794 +0100
+++ node-v0.10.29/deps/v8/tools/js2c.py 2014-07-21 00:59:21.663977922 +0100
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
#
# Copyright 2012 the V8 project authors. All rights reserved.
# Redistribution and use in source and binary forms, with or without
diff -urN node-v0.10.29.orig/deps/v8/tools/jsmin.py node-v0.10.29/deps/v8/tools/jsmin.py
--- node-v0.10.29.orig/deps/v8/tools/jsmin.py 2014-07-21 00:59:16.287874794 +0100
+++ node-v0.10.29/deps/v8/tools/jsmin.py 2014-07-21 00:59:21.714003697 +0100
@@ -1,4 +1,4 @@
-#!/usr/bin/python2.4
+#!/usr/bin/python2
# Copyright 2012 the V8 project authors. All rights reserved.
# Redistribution and use in source and binary forms, with or without
diff -urN node-v0.10.29.orig/deps/v8/tools/ll_prof.py node-v0.10.29/deps/v8/tools/ll_prof.py
--- node-v0.10.29.orig/deps/v8/tools/ll_prof.py 2014-07-21 00:59:16.287874794 +0100
+++ node-v0.10.29/deps/v8/tools/ll_prof.py 2014-07-21 00:59:21.643967593 +0100
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
#
# Copyright 2012 the V8 project authors. All rights reserved.
# Redistribution and use in source and binary forms, with or without
diff -urN node-v0.10.29.orig/deps/v8/tools/presubmit.py node-v0.10.29/deps/v8/tools/presubmit.py
--- node-v0.10.29.orig/deps/v8/tools/presubmit.py 2014-07-21 00:59:16.287874794 +0100
+++ node-v0.10.29/deps/v8/tools/presubmit.py 2014-07-21 00:59:21.747354226 +0100
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
#
# Copyright 2012 the V8 project authors. All rights reserved.
# Redistribution and use in source and binary forms, with or without
@@ -240,7 +240,7 @@
command = ['cpplint.py', '--filter', filt]
local_cpplint = join(path, "tools", "cpplint.py")
if exists(local_cpplint):
- command = ['python', local_cpplint, '--filter', filt]
+ command = ['python2', local_cpplint, '--filter', filt]
commands = join([command + [file] for file in files])
count = multiprocessing.cpu_count()
diff -urN node-v0.10.29.orig/deps/v8/tools/process-heap-prof.py node-v0.10.29/deps/v8/tools/process-heap-prof.py
--- node-v0.10.29.orig/deps/v8/tools/process-heap-prof.py 2014-07-21 00:59:16.287874794 +0100
+++ node-v0.10.29/deps/v8/tools/process-heap-prof.py 2014-07-21 00:59:21.687323260 +0100
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
#
# Copyright 2009 the V8 project authors. All rights reserved.
# Redistribution and use in source and binary forms, with or without
diff -urN node-v0.10.29.orig/deps/v8/tools/run-tests.py node-v0.10.29/deps/v8/tools/run-tests.py
--- node-v0.10.29.orig/deps/v8/tools/run-tests.py 2014-07-21 00:59:16.287874794 +0100
+++ node-v0.10.29/deps/v8/tools/run-tests.py 2014-07-21 00:59:21.837400581 +0100
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
#
# Copyright 2012 the V8 project authors. All rights reserved.
# Redistribution and use in source and binary forms, with or without
diff -urN node-v0.10.29.orig/deps/v8/tools/run-valgrind.py node-v0.10.29/deps/v8/tools/run-valgrind.py
--- node-v0.10.29.orig/deps/v8/tools/run-valgrind.py 2014-07-21 00:59:16.287874794 +0100
+++ node-v0.10.29/deps/v8/tools/run-valgrind.py 2014-07-21 00:59:21.737349021 +0100
@@ -1,4 +1,4 @@
-#!/usr/bin/python
+#!/usr/bin/python2
#
# Copyright 2009 the V8 project authors. All rights reserved.
# Redistribution and use in source and binary forms, with or without
diff -urN node-v0.10.29.orig/deps/v8/tools/stats-viewer.py node-v0.10.29/deps/v8/tools/stats-viewer.py
--- node-v0.10.29.orig/deps/v8/tools/stats-viewer.py 2014-07-21 00:59:16.287874794 +0100
+++ node-v0.10.29/deps/v8/tools/stats-viewer.py 2014-07-21 00:59:21.860745960 +0100
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
#
# Copyright 2008 the V8 project authors. All rights reserved.
# Redistribution and use in source and binary forms, with or without
diff -urN node-v0.10.29.orig/deps/v8/tools/status-file-converter.py node-v0.10.29/deps/v8/tools/status-file-converter.py
--- node-v0.10.29.orig/deps/v8/tools/status-file-converter.py 2014-07-21 00:59:16.287874794 +0100
+++ node-v0.10.29/deps/v8/tools/status-file-converter.py 2014-07-21 00:59:21.844070737 +0100
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
#
# Copyright 2012 the V8 project authors. All rights reserved.
# Redistribution and use in source and binary forms, with or without
diff -urN node-v0.10.29.orig/deps/v8/tools/test.py node-v0.10.29/deps/v8/tools/test.py
--- node-v0.10.29.orig/deps/v8/tools/test.py 2014-07-21 00:59:16.287874794 +0100
+++ node-v0.10.29/deps/v8/tools/test.py 2014-07-21 00:59:21.693993356 +0100
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
#
# Copyright 2012 the V8 project authors. All rights reserved.
# Redistribution and use in source and binary forms, with or without
diff -urN node-v0.10.29.orig/deps/v8/tools/testrunner/server/daemon.py node-v0.10.29/deps/v8/tools/testrunner/server/daemon.py
--- node-v0.10.29.orig/deps/v8/tools/testrunner/server/daemon.py 2014-07-21 00:59:16.287874794 +0100
+++ node-v0.10.29/deps/v8/tools/testrunner/server/daemon.py 2014-07-21 00:59:21.810720210 +0100
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
# This code has been written by Sander Marechal and published at:
# http://www.jejik.com/articles/2007/02/a_simple_unix_linux_daemon_in_python/
diff -urN node-v0.10.29.orig/deps/v8/tools/test-server.py node-v0.10.29/deps/v8/tools/test-server.py
--- node-v0.10.29.orig/deps/v8/tools/test-server.py 2014-07-21 00:59:16.287874794 +0100
+++ node-v0.10.29/deps/v8/tools/test-server.py 2014-07-21 00:59:21.707333552 +0100
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
#
# Copyright 2012 the V8 project authors. All rights reserved.
# Redistribution and use in source and binary forms, with or without
diff -urN node-v0.10.29.orig/deps/v8/tools/test-wrapper-gypbuild.py node-v0.10.29/deps/v8/tools/test-wrapper-gypbuild.py
--- node-v0.10.29.orig/deps/v8/tools/test-wrapper-gypbuild.py 2014-07-21 00:59:16.287874794 +0100
+++ node-v0.10.29/deps/v8/tools/test-wrapper-gypbuild.py 2014-07-21 00:59:21.840735671 +0100
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
#
# Copyright 2012 the V8 project authors. All rights reserved.
# Redistribution and use in source and binary forms, with or without
diff -urN node-v0.10.29.orig/test/pummel/test-child-process-spawn-loop.js node-v0.10.29/test/pummel/test-child-process-spawn-loop.js
--- node-v0.10.29.orig/test/pummel/test-child-process-spawn-loop.js 2014-07-21 00:59:16.257859373 +0100
+++ node-v0.10.29/test/pummel/test-child-process-spawn-loop.js 2014-07-21 00:59:34.750720172 +0100
@@ -34,7 +34,7 @@
var finished = false;
function doSpawn(i) {
- var child = spawn('python', ['-c', 'print ' + SIZE + ' * "C"']);
+ var child = spawn('python2', ['-c', 'print ' + SIZE + ' * "C"']);
var count = 0;
child.stdout.setEncoding('ascii');
diff -urN node-v0.10.29.orig/test/pummel/test-exec.js node-v0.10.29/test/pummel/test-exec.js
--- node-v0.10.29.orig/test/pummel/test-exec.js 2014-07-21 00:59:16.257859373 +0100
+++ node-v0.10.29/test/pummel/test-exec.js 2014-07-21 00:59:34.757390311 +0100
@@ -110,7 +110,7 @@
}
-exec('python -c "print 200000*\'C\'"', {maxBuffer: 1000},
+exec('python2 -c "print 200000*\'C\'"', {maxBuffer: 1000},
function(err, stdout, stderr) {
assert.ok(err);
assert.ok(/maxBuffer/.test(err.message));
diff -urN node-v0.10.29.orig/test/simple/test-child-process-set-blocking.js node-v0.10.29/test/simple/test-child-process-set-blocking.js
--- node-v0.10.29.orig/test/simple/test-child-process-set-blocking.js 2014-07-21 00:59:16.261194398 +0100
+++ node-v0.10.29/test/simple/test-child-process-set-blocking.js 2014-07-21 00:59:35.200952142 +0100
@@ -26,7 +26,7 @@
var SIZE = 100000;
var childGone = false;
-var cp = ch.spawn('python', ['-c', 'print ' + SIZE + ' * "C"'], {
+var cp = ch.spawn('python2', ['-c', 'print ' + SIZE + ' * "C"'], {
customFds: [0, 1, 2]
});
diff -urN node-v0.10.29.orig/tools/closure_linter/closure_linter/checkerbase.py node-v0.10.29/tools/closure_linter/closure_linter/checkerbase.py
--- node-v0.10.29.orig/tools/closure_linter/closure_linter/checkerbase.py 2014-07-21 00:59:16.251189248 +0100
+++ node-v0.10.29/tools/closure_linter/closure_linter/checkerbase.py 2014-07-21 00:59:16.921534607 +0100
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
#
# Copyright 2008 The Closure Linter Authors. All Rights Reserved.
#
diff -urN node-v0.10.29.orig/tools/closure_linter/closure_linter/checker.py node-v0.10.29/tools/closure_linter/closure_linter/checker.py
--- node-v0.10.29.orig/tools/closure_linter/closure_linter/checker.py 2014-07-21 00:59:16.251189248 +0100
+++ node-v0.10.29/tools/closure_linter/closure_linter/checker.py 2014-07-21 00:59:16.934874827 +0100
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
#
# Copyright 2007 The Closure Linter Authors. All Rights Reserved.
#
diff -urN node-v0.10.29.orig/tools/closure_linter/closure_linter/common/erroraccumulator.py node-v0.10.29/tools/closure_linter/closure_linter/common/erroraccumulator.py
--- node-v0.10.29.orig/tools/closure_linter/closure_linter/common/erroraccumulator.py 2014-07-21 00:59:16.251189248 +0100
+++ node-v0.10.29/tools/closure_linter/closure_linter/common/erroraccumulator.py 2014-07-21 00:59:16.961555239 +0100
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
#
# Copyright 2008 The Closure Linter Authors. All Rights Reserved.
#
diff -urN node-v0.10.29.orig/tools/closure_linter/closure_linter/common/errorhandler.py node-v0.10.29/tools/closure_linter/closure_linter/common/errorhandler.py
--- node-v0.10.29.orig/tools/closure_linter/closure_linter/common/errorhandler.py 2014-07-21 00:59:16.251189248 +0100
+++ node-v0.10.29/tools/closure_linter/closure_linter/common/errorhandler.py 2014-07-21 00:59:16.968225328 +0100
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
#
# Copyright 2008 The Closure Linter Authors. All Rights Reserved.
#
diff -urN node-v0.10.29.orig/tools/closure_linter/closure_linter/common/errorprinter.py node-v0.10.29/tools/closure_linter/closure_linter/common/errorprinter.py
--- node-v0.10.29.orig/tools/closure_linter/closure_linter/common/errorprinter.py 2014-07-21 00:59:16.251189248 +0100
+++ node-v0.10.29/tools/closure_linter/closure_linter/common/errorprinter.py 2014-07-21 00:59:16.941544912 +0100
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
#
# Copyright 2008 The Closure Linter Authors. All Rights Reserved.
#
diff -urN node-v0.10.29.orig/tools/closure_linter/closure_linter/common/error.py node-v0.10.29/tools/closure_linter/closure_linter/common/error.py
--- node-v0.10.29.orig/tools/closure_linter/closure_linter/common/error.py 2014-07-21 00:59:16.251189248 +0100
+++ node-v0.10.29/tools/closure_linter/closure_linter/common/error.py 2014-07-21 00:59:16.964890283 +0100
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
#
# Copyright 2007 The Closure Linter Authors. All Rights Reserved.
#
diff -urN node-v0.10.29.orig/tools/closure_linter/closure_linter/common/filetestcase.py node-v0.10.29/tools/closure_linter/closure_linter/common/filetestcase.py
--- node-v0.10.29.orig/tools/closure_linter/closure_linter/common/filetestcase.py 2014-07-21 00:59:16.251189248 +0100
+++ node-v0.10.29/tools/closure_linter/closure_linter/common/filetestcase.py 2014-07-21 00:59:16.964890283 +0100
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
#
# Copyright 2007 The Closure Linter Authors. All Rights Reserved.
#
diff -urN node-v0.10.29.orig/tools/closure_linter/closure_linter/common/htmlutil.py node-v0.10.29/tools/closure_linter/closure_linter/common/htmlutil.py
--- node-v0.10.29.orig/tools/closure_linter/closure_linter/common/htmlutil.py 2014-07-21 00:59:16.251189248 +0100
+++ node-v0.10.29/tools/closure_linter/closure_linter/common/htmlutil.py 2014-07-21 00:59:16.948215040 +0100
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
#
# Copyright 2007 The Closure Linter Authors. All Rights Reserved.
#
diff -urN node-v0.10.29.orig/tools/closure_linter/closure_linter/common/__init__.py node-v0.10.29/tools/closure_linter/closure_linter/common/__init__.py
--- node-v0.10.29.orig/tools/closure_linter/closure_linter/common/__init__.py 2014-07-21 00:59:16.251189248 +0100
+++ node-v0.10.29/tools/closure_linter/closure_linter/common/__init__.py 2014-07-21 00:59:16.938209866 +0100
@@ -1 +1 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
diff -urN node-v0.10.29.orig/tools/closure_linter/closure_linter/common/lintrunner.py node-v0.10.29/tools/closure_linter/closure_linter/common/lintrunner.py
--- node-v0.10.29.orig/tools/closure_linter/closure_linter/common/lintrunner.py 2014-07-21 00:59:16.251189248 +0100
+++ node-v0.10.29/tools/closure_linter/closure_linter/common/lintrunner.py 2014-07-21 00:59:16.944879968 +0100
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
#
# Copyright 2008 The Closure Linter Authors. All Rights Reserved.
#
diff -urN node-v0.10.29.orig/tools/closure_linter/closure_linter/common/matcher.py node-v0.10.29/tools/closure_linter/closure_linter/common/matcher.py
--- node-v0.10.29.orig/tools/closure_linter/closure_linter/common/matcher.py 2014-07-21 00:59:16.251189248 +0100
+++ node-v0.10.29/tools/closure_linter/closure_linter/common/matcher.py 2014-07-21 00:59:16.951550067 +0100
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
#
# Copyright 2007 The Closure Linter Authors. All Rights Reserved.
#
diff -urN node-v0.10.29.orig/tools/closure_linter/closure_linter/common/position.py node-v0.10.29/tools/closure_linter/closure_linter/common/position.py
--- node-v0.10.29.orig/tools/closure_linter/closure_linter/common/position.py 2014-07-21 00:59:16.251189248 +0100
+++ node-v0.10.29/tools/closure_linter/closure_linter/common/position.py 2014-07-21 00:59:16.958220155 +0100
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
#
# Copyright 2008 The Closure Linter Authors. All Rights Reserved.
#
diff -urN node-v0.10.29.orig/tools/closure_linter/closure_linter/common/simplefileflags.py node-v0.10.29/tools/closure_linter/closure_linter/common/simplefileflags.py
--- node-v0.10.29.orig/tools/closure_linter/closure_linter/common/simplefileflags.py 2014-07-21 00:59:16.251189248 +0100
+++ node-v0.10.29/tools/closure_linter/closure_linter/common/simplefileflags.py 2014-07-21 00:59:16.951550067 +0100
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
#
# Copyright 2008 The Closure Linter Authors. All Rights Reserved.
#
diff -urN node-v0.10.29.orig/tools/closure_linter/closure_linter/common/tokenizer.py node-v0.10.29/tools/closure_linter/closure_linter/common/tokenizer.py
--- node-v0.10.29.orig/tools/closure_linter/closure_linter/common/tokenizer.py 2014-07-21 00:59:16.251189248 +0100
+++ node-v0.10.29/tools/closure_linter/closure_linter/common/tokenizer.py 2014-07-21 00:59:16.958220155 +0100
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
#
# Copyright 2007 The Closure Linter Authors. All Rights Reserved.
#
diff -urN node-v0.10.29.orig/tools/closure_linter/closure_linter/common/tokens.py node-v0.10.29/tools/closure_linter/closure_linter/common/tokens.py
--- node-v0.10.29.orig/tools/closure_linter/closure_linter/common/tokens.py 2014-07-21 00:59:16.251189248 +0100
+++ node-v0.10.29/tools/closure_linter/closure_linter/common/tokens.py 2014-07-21 00:59:16.944879968 +0100
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
#
# Copyright 2008 The Closure Linter Authors. All Rights Reserved.
#
diff -urN node-v0.10.29.orig/tools/closure_linter/closure_linter/ecmalintrules.py node-v0.10.29/tools/closure_linter/closure_linter/ecmalintrules.py
--- node-v0.10.29.orig/tools/closure_linter/closure_linter/ecmalintrules.py 2014-07-21 00:59:16.251189248 +0100
+++ node-v0.10.29/tools/closure_linter/closure_linter/ecmalintrules.py 2014-07-21 00:59:16.911529469 +0100
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
#
# Copyright 2008 The Closure Linter Authors. All Rights Reserved.
#
diff -urN node-v0.10.29.orig/tools/closure_linter/closure_linter/ecmametadatapass.py node-v0.10.29/tools/closure_linter/closure_linter/ecmametadatapass.py
--- node-v0.10.29.orig/tools/closure_linter/closure_linter/ecmametadatapass.py 2014-07-21 00:59:16.251189248 +0100
+++ node-v0.10.29/tools/closure_linter/closure_linter/ecmametadatapass.py 2014-07-21 00:59:16.934874827 +0100
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
#
# Copyright 2010 The Closure Linter Authors. All Rights Reserved.
#
diff -urN node-v0.10.29.orig/tools/closure_linter/closure_linter/error_fixer.py node-v0.10.29/tools/closure_linter/closure_linter/error_fixer.py
--- node-v0.10.29.orig/tools/closure_linter/closure_linter/error_fixer.py 2014-07-21 00:59:16.251189248 +0100
+++ node-v0.10.29/tools/closure_linter/closure_linter/error_fixer.py 2014-07-21 00:59:16.891519136 +0100
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
#
# Copyright 2007 The Closure Linter Authors. All Rights Reserved.
#
diff -urN node-v0.10.29.orig/tools/closure_linter/closure_linter/errorrules.py node-v0.10.29/tools/closure_linter/closure_linter/errorrules.py
--- node-v0.10.29.orig/tools/closure_linter/closure_linter/errorrules.py 2014-07-21 00:59:16.251189248 +0100
+++ node-v0.10.29/tools/closure_linter/closure_linter/errorrules.py 2014-07-21 00:59:16.914864508 +0100
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
#
# Copyright 2010 The Closure Linter Authors. All Rights Reserved.
#
diff -urN node-v0.10.29.orig/tools/closure_linter/closure_linter/errors.py node-v0.10.29/tools/closure_linter/closure_linter/errors.py
--- node-v0.10.29.orig/tools/closure_linter/closure_linter/errors.py 2014-07-21 00:59:16.251189248 +0100
+++ node-v0.10.29/tools/closure_linter/closure_linter/errors.py 2014-07-21 00:59:16.888184100 +0100
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
#
# Copyright 2007 The Closure Linter Authors. All Rights Reserved.
#
diff -urN node-v0.10.29.orig/tools/closure_linter/closure_linter/fixjsstyle.py node-v0.10.29/tools/closure_linter/closure_linter/fixjsstyle.py
--- node-v0.10.29.orig/tools/closure_linter/closure_linter/fixjsstyle.py 2014-07-21 00:59:16.251189248 +0100
+++ node-v0.10.29/tools/closure_linter/closure_linter/fixjsstyle.py 2014-07-21 00:59:16.924869678 +0100
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
#
# Copyright 2007 The Closure Linter Authors. All Rights Reserved.
#
diff -urN node-v0.10.29.orig/tools/closure_linter/closure_linter/fixjsstyle_test.py node-v0.10.29/tools/closure_linter/closure_linter/fixjsstyle_test.py
--- node-v0.10.29.orig/tools/closure_linter/closure_linter/fixjsstyle_test.py 2014-07-21 00:59:16.251189248 +0100
+++ node-v0.10.29/tools/closure_linter/closure_linter/fixjsstyle_test.py 2014-07-21 00:59:16.884849067 +0100
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
#
# Copyright 2008 The Closure Linter Authors. All Rights Reserved.
#
diff -urN node-v0.10.29.orig/tools/closure_linter/closure_linter/full_test.py node-v0.10.29/tools/closure_linter/closure_linter/full_test.py
--- node-v0.10.29.orig/tools/closure_linter/closure_linter/full_test.py 2014-07-21 00:59:16.251189248 +0100
+++ node-v0.10.29/tools/closure_linter/closure_linter/full_test.py 2014-07-21 00:59:16.884849067 +0100
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
#
# Copyright 2007 The Closure Linter Authors. All Rights Reserved.
#
diff -urN node-v0.10.29.orig/tools/closure_linter/closure_linter/gjslint.py node-v0.10.29/tools/closure_linter/closure_linter/gjslint.py
--- node-v0.10.29.orig/tools/closure_linter/closure_linter/gjslint.py 2014-07-21 00:59:16.251189248 +0100
+++ node-v0.10.29/tools/closure_linter/closure_linter/gjslint.py 2014-07-21 00:59:16.904859332 +0100
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
#
# Copyright 2007 The Closure Linter Authors. All Rights Reserved.
#
diff -urN node-v0.10.29.orig/tools/closure_linter/closure_linter/indentation.py node-v0.10.29/tools/closure_linter/closure_linter/indentation.py
--- node-v0.10.29.orig/tools/closure_linter/closure_linter/indentation.py 2014-07-21 00:59:16.251189248 +0100
+++ node-v0.10.29/tools/closure_linter/closure_linter/indentation.py 2014-07-21 00:59:16.898189262 +0100
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
#
# Copyright 2010 The Closure Linter Authors. All Rights Reserved.
#
diff -urN node-v0.10.29.orig/tools/closure_linter/closure_linter/__init__.py node-v0.10.29/tools/closure_linter/closure_linter/__init__.py
--- node-v0.10.29.orig/tools/closure_linter/closure_linter/__init__.py 2014-07-21 00:59:16.251189248 +0100
+++ node-v0.10.29/tools/closure_linter/closure_linter/__init__.py 2014-07-21 00:59:16.881513985 +0100
@@ -1 +1 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
diff -urN node-v0.10.29.orig/tools/closure_linter/closure_linter/javascriptlintrules.py node-v0.10.29/tools/closure_linter/closure_linter/javascriptlintrules.py
--- node-v0.10.29.orig/tools/closure_linter/closure_linter/javascriptlintrules.py 2014-07-21 00:59:16.251189248 +0100
+++ node-v0.10.29/tools/closure_linter/closure_linter/javascriptlintrules.py 2014-07-21 00:59:16.894854187 +0100
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
#
# Copyright 2008 The Closure Linter Authors. All Rights Reserved.
#
diff -urN node-v0.10.29.orig/tools/closure_linter/closure_linter/javascriptstatetracker.py node-v0.10.29/tools/closure_linter/closure_linter/javascriptstatetracker.py
--- node-v0.10.29.orig/tools/closure_linter/closure_linter/javascriptstatetracker.py 2014-07-21 00:59:16.251189248 +0100
+++ node-v0.10.29/tools/closure_linter/closure_linter/javascriptstatetracker.py 2014-07-21 00:59:16.901524290 +0100
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
#
# Copyright 2008 The Closure Linter Authors. All Rights Reserved.
#
diff -urN node-v0.10.29.orig/tools/closure_linter/closure_linter/javascriptstatetracker_test.py node-v0.10.29/tools/closure_linter/closure_linter/javascriptstatetracker_test.py
--- node-v0.10.29.orig/tools/closure_linter/closure_linter/javascriptstatetracker_test.py 2014-07-21 00:59:16.251189248 +0100
+++ node-v0.10.29/tools/closure_linter/closure_linter/javascriptstatetracker_test.py 2014-07-21 00:59:16.914864508 +0100
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
#
# Copyright 2010 The Closure Linter Authors. All Rights Reserved.
#
diff -urN node-v0.10.29.orig/tools/closure_linter/closure_linter/javascripttokenizer.py node-v0.10.29/tools/closure_linter/closure_linter/javascripttokenizer.py
--- node-v0.10.29.orig/tools/closure_linter/closure_linter/javascripttokenizer.py 2014-07-21 00:59:16.251189248 +0100
+++ node-v0.10.29/tools/closure_linter/closure_linter/javascripttokenizer.py 2014-07-21 00:59:16.931539745 +0100
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
#
# Copyright 2007 The Closure Linter Authors. All Rights Reserved.
#
diff -urN node-v0.10.29.orig/tools/closure_linter/closure_linter/javascripttokens.py node-v0.10.29/tools/closure_linter/closure_linter/javascripttokens.py
--- node-v0.10.29.orig/tools/closure_linter/closure_linter/javascripttokens.py 2014-07-21 00:59:16.251189248 +0100
+++ node-v0.10.29/tools/closure_linter/closure_linter/javascripttokens.py 2014-07-21 00:59:16.928204696 +0100
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
#
# Copyright 2008 The Closure Linter Authors. All Rights Reserved.
#
diff -urN node-v0.10.29.orig/tools/closure_linter/closure_linter/statetracker.py node-v0.10.29/tools/closure_linter/closure_linter/statetracker.py
--- node-v0.10.29.orig/tools/closure_linter/closure_linter/statetracker.py 2014-07-21 00:59:16.251189248 +0100
+++ node-v0.10.29/tools/closure_linter/closure_linter/statetracker.py 2014-07-21 00:59:16.908194388 +0100
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
#
# Copyright 2007 The Closure Linter Authors. All Rights Reserved.
#
diff -urN node-v0.10.29.orig/tools/closure_linter/closure_linter/tokenutil.py node-v0.10.29/tools/closure_linter/closure_linter/tokenutil.py
--- node-v0.10.29.orig/tools/closure_linter/closure_linter/tokenutil.py 2014-07-21 00:59:16.251189248 +0100
+++ node-v0.10.29/tools/closure_linter/closure_linter/tokenutil.py 2014-07-21 00:59:16.918199554 +0100
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
#
# Copyright 2007 The Closure Linter Authors. All Rights Reserved.
#
diff -urN node-v0.10.29.orig/tools/closure_linter/gflags.py node-v0.10.29/tools/closure_linter/gflags.py
--- node-v0.10.29.orig/tools/closure_linter/gflags.py 2014-07-21 00:59:16.251189248 +0100
+++ node-v0.10.29/tools/closure_linter/gflags.py 2014-07-21 00:59:16.994905734 +0100
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
# Copyright (c) 2007, Google Inc.
# All rights reserved.
diff -urN node-v0.10.29.orig/tools/closure_linter/setup.py node-v0.10.29/tools/closure_linter/setup.py
--- node-v0.10.29.orig/tools/closure_linter/setup.py 2014-07-21 00:59:16.251189248 +0100
+++ node-v0.10.29/tools/closure_linter/setup.py 2014-07-21 00:59:16.974895452 +0100
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
#
# Copyright 2010 The Closure Linter Authors. All Rights Reserved.
#
diff -urN node-v0.10.29.orig/tools/cpplint.py node-v0.10.29/tools/cpplint.py
--- node-v0.10.29.orig/tools/cpplint.py 2014-07-21 00:59:16.251189248 +0100
+++ node-v0.10.29/tools/cpplint.py 2014-07-21 00:59:17.114967590 +0100
@@ -1,4 +1,4 @@
-#!/usr/bin/python2.4
+#!/usr/bin/python2
#
# Copyright (c) 2009 Google Inc. All rights reserved.
#
diff -urN node-v0.10.29.orig/tools/genv8constants.py node-v0.10.29/tools/genv8constants.py
--- node-v0.10.29.orig/tools/genv8constants.py 2014-07-21 00:59:16.254524294 +0100
+++ node-v0.10.29/tools/genv8constants.py 2014-07-21 00:59:17.164993353 +0100
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
#
# genv8constants.py output_file libv8_base.a
diff -urN node-v0.10.29.orig/tools/gyp/buildbot/buildbot_run.py node-v0.10.29/tools/gyp/buildbot/buildbot_run.py
--- node-v0.10.29.orig/tools/gyp/buildbot/buildbot_run.py 2014-07-21 00:59:16.247854207 +0100
+++ node-v0.10.29/tools/gyp/buildbot/buildbot_run.py 2014-07-21 00:59:16.671405759 +0100
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
# Copyright (c) 2012 Google Inc. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
# found in the LICENSE file.
diff -urN node-v0.10.29.orig/tools/gyp/gyp_main.py node-v0.10.29/tools/gyp/gyp_main.py
--- node-v0.10.29.orig/tools/gyp/gyp_main.py 2014-07-21 00:59:16.247854207 +0100
+++ node-v0.10.29/tools/gyp/gyp_main.py 2014-07-21 00:59:16.658065548 +0100
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
# Copyright (c) 2009 Google Inc. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
diff -urN node-v0.10.29.orig/tools/gyp/gyptest.py node-v0.10.29/tools/gyp/gyptest.py
--- node-v0.10.29.orig/tools/gyp/gyptest.py 2014-07-21 00:59:16.251189248 +0100
+++ node-v0.10.29/tools/gyp/gyptest.py 2014-07-21 00:59:16.808142841 +0100
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
# Copyright (c) 2012 Google Inc. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
diff -urN node-v0.10.29.orig/tools/gyp/pylib/gyp/common_test.py node-v0.10.29/tools/gyp/pylib/gyp/common_test.py
--- node-v0.10.29.orig/tools/gyp/pylib/gyp/common_test.py 2014-07-21 00:59:16.251189248 +0100
+++ node-v0.10.29/tools/gyp/pylib/gyp/common_test.py 2014-07-21 00:59:16.791467590 +0100
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
# Copyright (c) 2012 Google Inc. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
diff -urN node-v0.10.29.orig/tools/gyp/pylib/gyp/easy_xml_test.py node-v0.10.29/tools/gyp/pylib/gyp/easy_xml_test.py
--- node-v0.10.29.orig/tools/gyp/pylib/gyp/easy_xml_test.py 2014-07-21 00:59:16.251189248 +0100
+++ node-v0.10.29/tools/gyp/pylib/gyp/easy_xml_test.py 2014-07-21 00:59:16.794802641 +0100
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
# Copyright (c) 2011 Google Inc. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
diff -urN node-v0.10.29.orig/tools/gyp/pylib/gyp/flock_tool.py node-v0.10.29/tools/gyp/pylib/gyp/flock_tool.py
--- node-v0.10.29.orig/tools/gyp/pylib/gyp/flock_tool.py 2014-07-21 00:59:16.251189248 +0100
+++ node-v0.10.29/tools/gyp/pylib/gyp/flock_tool.py 2014-07-21 00:59:16.801472743 +0100
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
# Copyright (c) 2011 Google Inc. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
# found in the LICENSE file.
diff -urN node-v0.10.29.orig/tools/gyp/pylib/gyp/generator/msvs_test.py node-v0.10.29/tools/gyp/pylib/gyp/generator/msvs_test.py
--- node-v0.10.29.orig/tools/gyp/pylib/gyp/generator/msvs_test.py 2014-07-21 00:59:16.251189248 +0100
+++ node-v0.10.29/tools/gyp/pylib/gyp/generator/msvs_test.py 2014-07-21 00:59:16.748111945 +0100
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
# Copyright (c) 2012 Google Inc. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
# found in the LICENSE file.
diff -urN node-v0.10.29.orig/tools/gyp/pylib/gyp/generator/ninja_test.py node-v0.10.29/tools/gyp/pylib/gyp/generator/ninja_test.py
--- node-v0.10.29.orig/tools/gyp/pylib/gyp/generator/ninja_test.py 2014-07-21 00:59:16.251189248 +0100
+++ node-v0.10.29/tools/gyp/pylib/gyp/generator/ninja_test.py 2014-07-21 00:59:16.758117061 +0100
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
# Copyright (c) 2012 Google Inc. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
diff -urN node-v0.10.29.orig/tools/gyp/pylib/gyp/generator/xcode_test.py node-v0.10.29/tools/gyp/pylib/gyp/generator/xcode_test.py
--- node-v0.10.29.orig/tools/gyp/pylib/gyp/generator/xcode_test.py 2014-07-21 00:59:16.251189248 +0100
+++ node-v0.10.29/tools/gyp/pylib/gyp/generator/xcode_test.py 2014-07-21 00:59:16.731436663 +0100
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
# Copyright (c) 2013 Google Inc. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
diff -urN node-v0.10.29.orig/tools/gyp/pylib/gyp/__init__.py node-v0.10.29/tools/gyp/pylib/gyp/__init__.py
--- node-v0.10.29.orig/tools/gyp/pylib/gyp/__init__.py 2014-07-21 00:59:16.247854207 +0100
+++ node-v0.10.29/tools/gyp/pylib/gyp/__init__.py 2014-07-21 00:59:16.678075834 +0100
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
# Copyright (c) 2012 Google Inc. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
diff -urN node-v0.10.29.orig/tools/gyp/pylib/gyp/input_test.py node-v0.10.29/tools/gyp/pylib/gyp/input_test.py
--- node-v0.10.29.orig/tools/gyp/pylib/gyp/input_test.py 2014-07-21 00:59:16.251189248 +0100
+++ node-v0.10.29/tools/gyp/pylib/gyp/input_test.py 2014-07-21 00:59:16.708091313 +0100
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
# Copyright 2013 Google Inc. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
diff -urN node-v0.10.29.orig/tools/gyp/pylib/gyp/mac_tool.py node-v0.10.29/tools/gyp/pylib/gyp/mac_tool.py
--- node-v0.10.29.orig/tools/gyp/pylib/gyp/mac_tool.py 2014-07-21 00:59:16.251189248 +0100
+++ node-v0.10.29/tools/gyp/pylib/gyp/mac_tool.py 2014-07-21 00:59:16.791467590 +0100
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
# Copyright (c) 2012 Google Inc. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
# found in the LICENSE file.
diff -urN node-v0.10.29.orig/tools/gyp/pylib/gyp/MSVSSettings_test.py node-v0.10.29/tools/gyp/pylib/gyp/MSVSSettings_test.py
--- node-v0.10.29.orig/tools/gyp/pylib/gyp/MSVSSettings_test.py 2014-07-21 00:59:16.251189248 +0100
+++ node-v0.10.29/tools/gyp/pylib/gyp/MSVSSettings_test.py 2014-07-21 00:59:16.804807784 +0100
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
# Copyright (c) 2012 Google Inc. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
diff -urN node-v0.10.29.orig/tools/gyp/pylib/gyp/win_tool.py node-v0.10.29/tools/gyp/pylib/gyp/win_tool.py
--- node-v0.10.29.orig/tools/gyp/pylib/gyp/win_tool.py 2014-07-21 00:59:16.251189248 +0100
+++ node-v0.10.29/tools/gyp/pylib/gyp/win_tool.py 2014-07-21 00:59:16.701421197 +0100
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
# Copyright (c) 2012 Google Inc. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
diff -urN node-v0.10.29.orig/tools/gyp/samples/samples node-v0.10.29/tools/gyp/samples/samples
--- node-v0.10.29.orig/tools/gyp/samples/samples 2014-07-21 00:59:16.247854207 +0100
+++ node-v0.10.29/tools/gyp/samples/samples 2014-07-21 00:59:16.661400578 +0100
@@ -1,4 +1,4 @@
-#!/usr/bin/python
+#!/usr/bin/python2
# Copyright (c) 2009 Google Inc. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
diff -urN node-v0.10.29.orig/tools/gyp/setup.py node-v0.10.29/tools/gyp/setup.py
--- node-v0.10.29.orig/tools/gyp/setup.py 2014-07-21 00:59:16.247854207 +0100
+++ node-v0.10.29/tools/gyp/setup.py 2014-07-21 00:59:16.668070680 +0100
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
# Copyright (c) 2009 Google Inc. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
diff -urN node-v0.10.29.orig/tools/gyp/tools/emacs/testdata/media.gyp node-v0.10.29/tools/gyp/tools/emacs/testdata/media.gyp
--- node-v0.10.29.orig/tools/gyp/tools/emacs/testdata/media.gyp 2014-07-21 00:59:16.251189248 +0100
+++ node-v0.10.29/tools/gyp/tools/emacs/testdata/media.gyp 2014-07-21 00:59:16.838158319 +0100
@@ -987,7 +987,7 @@
'<(SHARED_INTERMEDIATE_DIR)/media/jni/media_player_listener_jni.h',
],
'action': [
- 'python',
+ 'python2',
'<(DEPTH)/base/android/jni_generator/jni_generator.py',
'-o',
'<@(_inputs)',
diff -urN node-v0.10.29.orig/tools/gyp/tools/emacs/testdata/media.gyp.fontified node-v0.10.29/tools/gyp/tools/emacs/testdata/media.gyp.fontified
--- node-v0.10.29.orig/tools/gyp/tools/emacs/testdata/media.gyp.fontified 2014-07-21 00:59:16.251189248 +0100
+++ node-v0.10.29/tools/gyp/tools/emacs/testdata/media.gyp.fontified 2014-07-21 00:59:16.841493369 +0100
@@ -988,7 +988,7 @@
'<(SHARED_INTERMEDIATE_DIR)/media/jni/media_player_listener_jni.h',
],
'action': [
- 'python',
+ 'python2',
'<(DEPTH)/base/android/jni_generator/jni_generator.py',
'-o',
'<@(_inputs)',
diff -urN node-v0.10.29.orig/tools/gyp/tools/graphviz.py node-v0.10.29/tools/gyp/tools/graphviz.py
--- node-v0.10.29.orig/tools/gyp/tools/graphviz.py 2014-07-21 00:59:16.251189248 +0100
+++ node-v0.10.29/tools/gyp/tools/graphviz.py 2014-07-21 00:59:16.821483059 +0100
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
# Copyright (c) 2011 Google Inc. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
diff -urN node-v0.10.29.orig/tools/gyp/tools/pretty_gyp.py node-v0.10.29/tools/gyp/tools/pretty_gyp.py
--- node-v0.10.29.orig/tools/gyp/tools/pretty_gyp.py 2014-07-21 00:59:16.251189248 +0100
+++ node-v0.10.29/tools/gyp/tools/pretty_gyp.py 2014-07-21 00:59:16.818148006 +0100
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
# Copyright (c) 2012 Google Inc. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
diff -urN node-v0.10.29.orig/tools/gyp/tools/pretty_sln.py node-v0.10.29/tools/gyp/tools/pretty_sln.py
--- node-v0.10.29.orig/tools/gyp/tools/pretty_sln.py 2014-07-21 00:59:16.251189248 +0100
+++ node-v0.10.29/tools/gyp/tools/pretty_sln.py 2014-07-21 00:59:16.851498512 +0100
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
# Copyright (c) 2012 Google Inc. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
diff -urN node-v0.10.29.orig/tools/gyp/tools/pretty_vcproj.py node-v0.10.29/tools/gyp/tools/pretty_vcproj.py
--- node-v0.10.29.orig/tools/gyp/tools/pretty_vcproj.py 2014-07-21 00:59:16.251189248 +0100
+++ node-v0.10.29/tools/gyp/tools/pretty_vcproj.py 2014-07-21 00:59:16.814812961 +0100
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
# Copyright (c) 2012 Google Inc. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
diff -urN node-v0.10.29.orig/tools/gyp_node.py node-v0.10.29/tools/gyp_node.py
--- node-v0.10.29.orig/tools/gyp_node.py 2014-07-21 00:59:16.251189248 +0100
+++ node-v0.10.29/tools/gyp_node.py 2014-07-21 00:59:17.084952131 +0100
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/python2
import glob
import os
import shlex
diff -urN node-v0.10.29.orig/tools/install.py node-v0.10.29/tools/install.py
--- node-v0.10.29.orig/tools/install.py 2014-07-21 00:59:16.254524294 +0100
+++ node-v0.10.29/tools/install.py 2014-07-21 00:59:17.164993353 +0100
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
import errno
diff -urN node-v0.10.29.orig/tools/js2c.py node-v0.10.29/tools/js2c.py
--- node-v0.10.29.orig/tools/js2c.py 2014-07-21 00:59:16.251189248 +0100
+++ node-v0.10.29/tools/js2c.py 2014-07-21 00:59:16.998240812 +0100
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
#
# Copyright 2006-2008 the V8 project authors. All rights reserved.
# Redistribution and use in source and binary forms, with or without
diff -urN node-v0.10.29.orig/tools/specialize_node_d.py node-v0.10.29/tools/specialize_node_d.py
--- node-v0.10.29.orig/tools/specialize_node_d.py 2014-07-21 00:59:16.251189248 +0100
+++ node-v0.10.29/tools/specialize_node_d.py 2014-07-21 00:59:17.108297488 +0100
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
#
# specialize_node_d.py output_file src/node.d flavor arch
diff -urN node-v0.10.29.orig/tools/test.py node-v0.10.29/tools/test.py
--- node-v0.10.29.orig/tools/test.py 2014-07-21 00:59:16.251189248 +0100
+++ node-v0.10.29/tools/test.py 2014-07-21 00:59:17.081617085 +0100
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
#
# Copyright 2008 the V8 project authors. All rights reserved.
# Redistribution and use in source and binary forms, with or without
diff -urN node-v0.10.29.orig/deps/npm/node_modules/node-gyp/lib/configure.js node-v0.10.29/deps/npm/node_modules/node-gyp/lib/configure.js
--- node-v0.10.29.orig/deps/npm/node_modules/node-gyp/lib/configure.js 2014-07-21 00:59:16.357910894 +0100
+++ node-v0.10.29/deps/npm/node_modules/node-gyp/lib/configure.js 2014-07-21 00:59:31.078828446 +0100
@@ -22,7 +22,7 @@
function configure (gyp, argv, callback) {
- var python = gyp.opts.python || process.env.PYTHON || 'python'
+ var python = gyp.opts.python || process.env.PYTHON || 'python2'
, buildDir = path.resolve('build')
, configNames = [ 'config.gypi', 'common.gypi' ]
, configs = []
@@ -112,7 +112,7 @@
function getNodeDir () {
// 'python' should be set by now
process.env.PYTHON = python
if (gyp.opts.nodedir) {
@@ -112,7 +112,7 @@
function getNodeDir () {
- // 'python' should be set by now
+ // 'python2' should be set by now
process.env.PYTHON = python
if (gyp.opts.nodedir) {